This is a small package about numerical analysis.
The author is still learning it, and implemented some basic algorithm.
Not ensure to be correct, bugs may occur. Be careful if you want to use it.

How did you find this??